mkdir $PODS_TARGET_SRCROOT/build
cd $PODS_TARGET_SRCROOT/build

BRIDGE_DIR=$PODS_TARGET_SRCROOT/../bridge

export LIBRARY_OUTPUT_DIR=$PODS_TARGET_SRCROOT/build
export KRAKEN_JS_ENGINE=jsc

if [[ $SDK_NAME == *"simulator"* ]]; then
  export KRAKEN_BRIDGE_ARCH=SIMULATOR64
elif [[ "$ARCHS" == *"arm64"* ]]; then
  export KRAKEN_BRIDGE_ARCH=OS64
else
  export KRAKEN_BRIDGE_ARCH=OS
fi

debug_build() {
  CURRENT_BUILD_MODE=$(cat BUILD_MODE)
  if [[ $CURRENT_BUILD_MODE != "debug" ]]; then
    rm -r cmake-build-debug
  fi

  cmake -DCMAKE_BUILD_TYPE=Debug -DCMAKE_TOOLCHAIN_FILE=$BRIDGE_DIR/cmake/ios.toolchain.cmake -DPLATFORM=$KRAKEN_BRIDGE_ARCH -DENABLE_BITCODE=FALSE -G "Unix Makefiles" -B $PODS_TARGET_SRCROOT/build/cmake-build-debug -S $PODS_TARGET_SRCROOT/../bridge
  cmake --build $PODS_TARGET_SRCROOT/build/cmake-build-debug --target kraken -- -j 4
}

profile_build() {
  CURRENT_BUILD_MODE=$(cat BUILD_MODE)
  if [[ $CURRENT_BUILD_MODE != "profile" ]]; then
    rm -r cmake-build-profile
  fi

  cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_TOOLCHAIN_FILE=$BRIDGE_DIR/cmake/ios.toolchain.cmake -DPLATFORM=$KRAKEN_BRIDGE_ARCH -DENABLE_BITCODE=FALSE -DENABLE_PROFILE=true -G "Unix Makefiles" -B $PODS_TARGET_SRCROOT/build/cmake-build-profile -S $PODS_TARGET_SRCROOT/../bridge
  cmake --build $PODS_TARGET_SRCROOT/build/cmake-build-profile --config RelWithDebInfo --target kraken -- -j 4
}

release_build() {
  CURRENT_BUILD_MODE=$(cat BUILD_MODE)
  if [[ $CURRENT_BUILD_MODE != "release" ]]; then
    rm -r cmake-build-release
  fi

  cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_TOOLCHAIN_FILE=$BRIDGE_DIR/cmake/ios.toolchain.cmake -DPLATFORM=$KRAKEN_BRIDGE_ARCH -DENABLE_BITCODE=FALSE -G "Unix Makefiles" -B $PODS_TARGET_SRCROOT/build/cmake-build-release -S $PODS_TARGET_SRCROOT/../bridge
  cmake --build $PODS_TARGET_SRCROOT/build/cmake-build-release --config RelWithDebInfo --target kraken -- -j 4
  dsymutil $PODS_TARGET_SRCROOT/build/kraken_bridge.framework/kraken_bridge
  mv $PODS_TARGET_SRCROOT/build/kraken_bridge.framework/kraken_bridge.dSYM $PODS_TARGET_SRCROOT/build/
  strip -S -X -x $PODS_TARGET_SRCROOT/build/kraken_bridge.framework/kraken_bridge
}

if [ "$CONFIGURATION" = "Debug" ]; then
  debug_build
  echo "debug" > BUILD_MODE
elif [ "$CONFIGURATION" = "Profile" ]; then
  profile_build
  echo "profile" > BUILD_MODE
elif [ "$CONFIGURATION" = "Release" ]; then
  release_build
  echo "release" > BUILD_MODE
fi

